function gs=gensign(seq)
% GENSIGN computes a genome signature of a sequence S (i.e. the ratio
% between the frequency of the dinucleotide (say AT) and the product of the
% frequencies of its components (say A, and T).
%
%   GS=GENSIGN(SEQ) calculate the genome signature of a sequence. In the
%   results raws are A*, C*, G*, T*, columns are *A, *C, *G, *T
%
%   Example:
%
%       % Create a random sequence and compute the genome signature.
%       seq = randseq(240)
%       gs=gensign(seq)
%   
%   Reference: 
%
%   S.Karlin, A.M.Campbell, J. Mrazek, "Annu. Rev. Genet.", 32:185-225,
%   (1998).
%
%
% See also DNDENSITY, DIMERCOUNT, NTDENSITY, BASECOUNTFREQUENCY


if isstruct(seq)
    try
        seq = seqfromstruct(seq);
    catch
        rethrow(lasterror);
    end
end

[bases, frequency]= basecountfrequency(seq); 
% Calculate the frequency of the di-nucleotides
[dimers,matrix]=dimercount(seq); 
nt=['A' 'C' 'G' 'T'];
for i=1:4
    f(i)= getfield(frequency, nt(i));
end
gs=matrix./(f'*f); 

